"""
This is the setup file for installing get_env_pass

Example:
    - python setup.py install
"""
from setuptools import setup

setup(name='get_env_pass',
      version='1.0.1',
      description='get-env-pass python package',
      long_description='get-env-pass python package',
      url='https://github.com/ccavales3/python-getenvpass',
      author='Caesar Cavales',
      author_email='c.cavales3@gmail.com',
      license='MIT',
      packages=['get_env_pass'],
      zip_safe=False)
